@@ -1,7 +1,5 @@
 from .device_registry import DeviceRegistry
-from .discover_net import DiscoverNet
-from .discover_serial import DiscoverSerial
-from .eval import EvalException
+from .eval import RemoteError
 from .config_store import Config
 from .utilities import *
 from .version import __version__
